"B",
"J",
"J+",
"JA",
"Ja",
"JB",
"Jb",
"JC",
"Jc",
"JD",
"Jd",
"JE",
"Je",
"JF",
"Jf",
"JG",
"Jg",
"JH",
"Jh",
"JI",
"Ji",
"JJ",
"Jj",
"JK",
"Jk",
"JL",
"Jl",
"JM",
"Jm",
"JN",
"Jn",
"JO",
"Jo",
"JP",
"Jp",
"JQ",
"Jq",
"JR",
"Jr",
"JS",
"Js",
"JT",
"Jt",
"JU",
"Ju",
"JV",
"Jv",
"JW",
"Jw",
"JX",
"Jx",
"JY",
"Jy",
"JZ",
"Jz",
"R",
"RG",
"X",
"Y",
"Z",
"a",
"b",
"d",
"e",
"f",
"g",
"h",
"i",
"n",
"o",
"p",
"q",
"s",
"t",
"w",
"x"
